//A simple Circle struct with operator overloading examples
//  Created by Denise Byrnes on 2/8/17.
//  Copyright (c) 2017 Denise Byrnes. All rights reserved.
//
#include <iostream>

#ifndef Circle_h
#define Circle_h

using std::ostream;
using std::istream;

struct Circle {
    float xCenter, yCenter;
    float radius;
};

    //Creates a Circle object
    //pre:none
    //post: Circle is created with default values
    void CreateCircle(Circle &c);
    

    //Sets the x center value of a Circle object
    //pre:none
    //post: center c.x coordinate of Circle is set to x
    void setX(float x, Circle &c);
    
    //Sets the y center value of a Circle object
    //pre:none
    //post: center c.y coordinate of Circle is set to y
    void setY(float y, Circle &c);
    
    //Sets the radius value of a Circle object
    //pre:r >= 0
    //post: radius of Circle is set to r
    //checks: c.r >= 0
    void setRadius (float r, Circle &c);
    
    //Sets the x,y center values and radius of a Circle object
    //pre:r >= 0
    //post: center c.x coordinate of Circle is set to x
    //      center c.y coordinate of Circle is set to y
    //      radius of Circle is set to r
    //checks: r >= 0
    void setCircle(float x, float y, float r, Circle &c);
    
    //Accessors (getters)
    //Returns the x center value of a Circle object
    //pre:none
    //post: returns x center coordinate
    float getX(const Circle &c) ;
    
    //Returns the y center value of a Circle object
    //pre:none
    //post: returns y center coordinate
    float getY(const Circle &c) ;
    
    //Returns the radius of a Circle object
    //pre:none
    //post: returns radius of Circle
    float getRadius(const Circle &c) ;
    
    //Returns true if the radius of this circle is < radius of circle1
    //pre:none
    //post: true if radius of c < radius of c1, false otherwise, Circle objects are not modified
    bool operator<(const Circle &c, const Circle &c1);
    
    //Returns true if c is == c1
    //pre:none
    //post: true if this c == c1, false otherwise,
    //Circle objects are not modified
    bool operator==(const Circle &c, const Circle &c1);
    
    //Outputs a Circle object to the output stream
    //pre:none
    //post: Circle object is displayed
    ostream& operator<<(ostream & out, const Circle &c);
    
    //Inputs a Circle object from the input stream
    //pre:none
    //post: Circle object is read from input stream
    istream& operator>>(istream & in, Circle &c);



#endif
